@@ -22,6 +22,9 @@ class QueryTab(QWidget):
         self.current_df = None
         self.filter_widgets = []
         self.results_title_text = results_title
+        # Track preview mode - when True, tools should use full table data
+        self.is_preview_mode = False
+        self.preview_table_name = None  # Name of table being previewed
         self.init_ui()
         
     def init_ui(self):
@@ -401,6 +404,7 @@ class QueryTab(QWidget):
         explain_action = menu.addAction(f"Explain Column")
         encode_action = menu.addAction(f"One-Hot Encode")
         predict_action = menu.addAction(f"Predict Column")
+        discover_rules_action = menu.addAction(f"Discover Classification Rules (CN2)")
         
         # Execute the menu
         action = menu.exec(header.mapToGlobal(position))
@@ -425,6 +429,11 @@ class QueryTab(QWidget):
             if hasattr(self.parent, 'predict_column'):
                 self.parent.predict_column(col_name)
         
+        elif action == discover_rules_action:
+            # Call the discover classification rules method on the parent
+            if hasattr(self.parent, 'discover_classification_rules'):
+                self.parent.discover_classification_rules(col_name)
+        
         elif action == sort_asc_action:
             self.results_table.sortItems(idx, Qt.SortOrder.AscendingOrder)
             self.parent.statusBar().showMessage(f"Sorted by '{col_name}' (ascending)")
@@ -673,6 +682,7 @@ class QueryTab(QWidget):
         explain_action = menu.addAction(f"Explain Column")
         encode_action = menu.addAction(f"One-Hot Encode")
         predict_action = menu.addAction(f"Predict Column")
+        discover_rules_action = menu.addAction(f"Discover Classification Rules (CN2)")
         
         # Execute the menu
         action = menu.exec(position)
@@ -697,6 +707,11 @@ class QueryTab(QWidget):
             if hasattr(self.parent, 'predict_column'):
                 self.parent.predict_column(col_name)
         
+        elif action == discover_rules_action:
+            # Call the discover classification rules method on the parent
+            if hasattr(self.parent, 'discover_classification_rules'):
+                self.parent.discover_classification_rules(col_name)
+        
         elif action == sort_asc_action:
             self.results_table.sortItems(idx, Qt.SortOrder.AscendingOrder)
             self.parent.statusBar().showMessage(f"Sorted by '{col_name}' (ascending)")
